Change Log
----------

0.2.0 released 2015-08-11
=========================

- fixed link in pypi docs
- converted to use webgrid
- make form work when DB URL is set to None

0.1.2 released 2012-06-11
=========================

- remove control panel route from settings file
- make "Who to Contact" required

0.1.1 released 2011-08-16
=========================

- fix MANIFEST.in so that template files are included

0.1.0 released 2011-08-16
=========================

- initial release
